@@ -8,7 +8,7 @@ use Capture::Tiny qw( capture );
 use Carp ();
 
 # ABSTRACT: Alien::Build installer code for ExtUtils::MakeMaker
-our $VERSION = '1.09_01'; # TRIAL VERSION
+our $VERSION = '1.11_01'; # TRIAL VERSION
 $VERSION = eval $VERSION;
 
 
@@ -334,7 +334,7 @@ Alien::Build::MM - Alien::Build installer code for ExtUtils::MakeMaker
 
 =head1 VERSION
 
-version 1.09_01
+version 1.11_01
 
 =head1 SYNOPSIS
 
@@ -456,7 +456,7 @@ Brian Wightman (MidLifeXis)
 
 Zaki Mughal (zmughal)
 
-mohawk2
+mohawk (mohawk2, ETJ)
 
 Vikas N Kumar (vikasnkumar)
 
@@ -474,6 +474,10 @@ Nicholas Shipp (nshp)
 
 Juan Julián Merelo Guervós (JJ)
 
+Joel Berger (JBERGER)
+
+Petr Pisar (ppisar)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2017 by Graham Ollis.
