@@ -8,7 +8,7 @@ use Capture::Tiny qw( capture );
 use Alien::Build::Plugin;
 
 # ABSTRACT: Make plugin for Alien::Build
-our $VERSION = '1.09_01'; # TRIAL VERSION
+our $VERSION = '1.11_01'; # TRIAL VERSION
 $VERSION = eval $VERSION;
 
 
@@ -80,7 +80,7 @@ Alien::Build::Plugin::Build::Make - Make plugin for Alien::Build
 
 =head1 VERSION
 
-version 1.09_01
+version 1.11_01
 
 =head1 SYNOPSIS
 
@@ -162,7 +162,7 @@ Brian Wightman (MidLifeXis)
 
 Zaki Mughal (zmughal)
 
-mohawk2
+mohawk (mohawk2, ETJ)
 
 Vikas N Kumar (vikasnkumar)
 
@@ -180,6 +180,10 @@ Nicholas Shipp (nshp)
 
 Juan Julián Merelo Guervós (JJ)
 
+Joel Berger (JBERGER)
+
+Petr Pisar (ppisar)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2017 by Graham Ollis.
