@@ -7,7 +7,7 @@ use File::Basename ();
 use Carp ();
 
 # ABSTRACT: LWP plugin for fetching files
-our $VERSION = '1.09_01'; # TRIAL VERSION
+our $VERSION = '1.11_01'; # TRIAL VERSION
 $VERSION = eval $VERSION;
 
 
@@ -99,7 +99,7 @@ Alien::Build::Plugin::Fetch::HTTPTiny - LWP plugin for fetching files
 
 =head1 VERSION
 
-version 1.09_01
+version 1.11_01
 
 =head1 SYNOPSIS
 
@@ -156,7 +156,7 @@ Brian Wightman (MidLifeXis)
 
 Zaki Mughal (zmughal)
 
-mohawk2
+mohawk (mohawk2, ETJ)
 
 Vikas N Kumar (vikasnkumar)
 
@@ -174,6 +174,10 @@ Nicholas Shipp (nshp)
 
 Juan Julián Merelo Guervós (JJ)
 
+Joel Berger (JBERGER)
+
+Petr Pisar (ppisar)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2017 by Graham Ollis.
