@@ -7,7 +7,7 @@ use base qw( Exporter );
 our @EXPORT_OK = qw( _read_win32_reg_dump );
 
 # ABSTRACT: Private utility functions for Alien::Build
-our $VERSION = '1.09_01'; # TRIAL VERSION
+our $VERSION = '1.11_01'; # TRIAL VERSION
 $VERSION = eval $VERSION;
 
 
@@ -83,7 +83,7 @@ Alien::Build::Util::Win32::RegistryDump - Private utility functions for Alien::B
 
 =head1 VERSION
 
-version 1.09_01
+version 1.11_01
 
 =head1 DESCRIPTION
 
@@ -121,7 +121,7 @@ Brian Wightman (MidLifeXis)
 
 Zaki Mughal (zmughal)
 
-mohawk2
+mohawk (mohawk2, ETJ)
 
 Vikas N Kumar (vikasnkumar)
 
@@ -139,6 +139,10 @@ Nicholas Shipp (nshp)
 
 Juan Julián Merelo Guervós (JJ)
 
+Joel Berger (JBERGER)
+
+Petr Pisar (ppisar)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2017 by Graham Ollis.
