@@ -5,7 +5,7 @@ use warnings;
 use base 'Test2::Require';
 
 # ABSTRACT: Skip a test file unless a C compiler is available
-our $VERSION = '1.09_01'; # TRIAL VERSION
+our $VERSION = '1.11_01'; # TRIAL VERSION
 $VERSION = eval $VERSION;
 
 
@@ -29,7 +29,7 @@ Test::Alien::CanCompile - Skip a test file unless a C compiler is available
 
 =head1 VERSION
 
-version 1.09_01
+version 1.11_01
 
 =head1 SYNOPSIS
 
@@ -70,7 +70,7 @@ Brian Wightman (MidLifeXis)
 
 Zaki Mughal (zmughal)
 
-mohawk2
+mohawk (mohawk2, ETJ)
 
 Vikas N Kumar (vikasnkumar)
 
@@ -88,6 +88,10 @@ Nicholas Shipp (nshp)
 
 Juan Julián Merelo Guervós (JJ)
 
+Joel Berger (JBERGER)
+
+Petr Pisar (ppisar)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2017 by Graham Ollis.
